CmakeGenerator enum

CMake build-system generator selection.

Inheritance
Available extensions

Values

msbuild → const CmakeGenerator

Visual Studio multi-config generator (MSBuild).

Produces Release/ and Debug/ subdirectories. This is the CMake default on Windows and requires no extra environment setup. Only applicable on Windows.

ninja → const CmakeGenerator

Ninja single-config generator.

Faster incremental builds. On Windows, requires the MSVC environment to be initialized (the builder invokes vcvarsall.bat automatically). On Linux, works out of the box if ninja is on PATH.

makefiles → const CmakeGenerator

Unix Makefiles single-config generator.

The CMake default on Linux when Ninja is not available. Slower than Ninja for incremental builds but requires no additional tools. Only applicable on Linux.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CmakeGenerator>
A constant List of the values in this enum, in order of their declaration.