generatorPath property
Explicit path to the generator executable.
For CmakeGenerator.ninja: path to the ninja binary when it is not
on PATH (e.g. /opt/ninja/bin/ninja).
When null, resolved via PATH.
Implementation
final String? generatorPath;
Explicit path to the generator executable.
For CmakeGenerator.ninja: path to the ninja binary when it is not
on PATH (e.g. /opt/ninja/bin/ninja).
When null, resolved via PATH.
final String? generatorPath;