DcbBuildOptions class final
Top-level build options that apply across all platforms.
Constructors
- DcbBuildOptions({bool? debug, bool parallel = true, bool copyCompileCommands = true, String compileCommandsPath = 'compile_commands.json'})
-
const
Properties
- compileCommandsPath → String
-
Relative path under the package root where
compile_commands.jsonis copied.final - copyCompileCommands → bool
-
Whether to generate and copy
compile_commands.jsonto the package root.final - debug → bool?
-
Whether to produce a Debug build.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- parallel → bool
-
Whether to enable parallel (multi-threaded) compilation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited